# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Perl-OSType
Version:	1.010
Release:	419.%{__distinit}%{__distvers}
Summary:	Map Perl operating system names to generic types
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Perl-OSType
Source0:	https://cpan.metacpan.org/modules/by-module/Perl/Perl-OSType-%{version}.tar.gz
Patch2:		Perl-OSType-1.010-stopwords.patch
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
# Module
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(constant)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Extra Tests (not run when bootstrapping due to multiple circular build deps)
%if 0%{!?perl_bootstrap:1}
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling), hunspell-en
BuildRequires:	perl(Test::Version)
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Modules that provide OS-specific behaviors often need to know if the current
operating system matches a more generic type of operating systems. For example,
'linux' is a type of 'Unix' operating system and so is 'freebsd'.

This module provides a mapping between an operating system name as given by $^O
and a more generic type. The initial version is based on the OS type mappings
provided in Module::Build and ExtUtils::CBuilder (thus, Microsoft operating
systems are given the type 'Windows' rather than 'Win32').

%prep
%setup -q -n Perl-OSType-%{version}

# More stopwords for the spell checker
%patch2

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
LANG=en_US make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes CONTRIBUTING.mkdn README
%{perl_vendorlib}/Perl/
%{_mandir}/man3/Perl::OSType.3*

%changelog
* Wed Nov  7 2018 Paul Howarth <paul@city-fan.org> - 1.010-419
- Explicitly BR: glibc-langpack-en

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.010-416
- Perl 5.28 rebuild

* Tue Apr 17 2018 Paul Howarth <paul@city-fan.org> - 1.010-396
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Wed Apr  5 2017 Paul Howarth <paul@city-fan.org> - 1.010-4
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88
  - Spell checker is always hunspell now

* Tue Mar  7 2017 Paul Howarth <paul@city-fan.org> - 1.010-3
- Fix FTBFS when perl is not in the minimal buildroot

* Wed Jun 22 2016 Paul Howarth <paul@city-fan.org> - 1.010-1
- Update to 1.010
  - Added 'msys' as a Unix-type OS
- BR: perl-generators where available
- Simplify find command using -delete
- Update patches as needed

* Tue Sep 22 2015 Paul Howarth <paul@city-fan.org> - 1.009-1
- Update to 1.009
  - Added 'sco' as a Unix-type OS
- Update patches as needed

* Fri Jan 30 2015 Paul Howarth <paul@city-fan.org> - 1.008-1
- Update to 1.008
  - Added 'minix' as a Unix-type OS
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Update patch for building on old distributions

* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 1.007-1
- Update to 1.007
  - Added 'android' as a Unix-type OS

* Thu Sep 26 2013 Paul Howarth <paul@city-fan.org> - 1.006-1
- Update to 1.006
  - Compile test could hang on Windows
  - Dropped configure_requires for ExtUtils::MakeMaker to 6.17
- Drop redundant patch for building with ExtUtils::MakeMaker < 6.30

* Wed Sep 11 2013 Paul Howarth <paul@city-fan.org> - 1.005-1
- Update to 1.005
  - Ensured no non-core test dependencies
  - Various non-functional changes to files and metadata included with
    the distribution
- Add patch with additional stopwords for the spell checker
- Update patches for building on old distributions

* Thu Aug 22 2013 Paul Howarth <paul@city-fan.org> - 1.004-1
- Update to 1.004
  - 'bitrig' is a Unix
- Specify all dependencies
- Update patches for building on old distributions
- Always use aspell for the spell check as Pod::Wordlist::hanekomu explicitly
  sets the speller to aspell

* Sun Jul 14 2013 Paul Howarth <paul@city-fan.org> - 1.003-3
- Perl 5.18 rebuild

* Thu Mar 21 2013 Paul Howarth <paul@city-fan.org> - 1.003-2
- Don't run the extra tests when bootstrapping

* Thu Mar 21 2013 Paul Howarth <paul@city-fan.org> - 1.003-1
- Update to 1.003
  - Fixed detection of VOS; $^O reports 'vos', not 'VOS'
  - Additional release tests
- BR: perl(File::Spec::Functions), perl(List::Util),
  perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire),
  perl(Pod::Wordlist::hanekomu), perl(Test::MinimumVersion),
  perl(Test::Perl::Critic), perl(Test::Spelling) and perl(Test::Version)
- Identify purpose of each build requirement
- Update patches for building on old distributions

* Sat Jul  7 2012 Paul Howarth <paul@city-fan.org> - 1.002-11
- BR: perl(constant), perl(Exporter) and perl(File::Temp)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 1.002-2
- Rebuild for perl 5.14.1 in Rawhide
- Install to vendor directories
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jan 25 2011 Paul Howarth <paul@city-fan.org> - 1.002-1
- Initial RPM version
